<template>
  <LoadingLayout :loading="isLoading">
    <Result
      v-bind="$attrs"
      :title="title"
      :orderNo="orderNo"
      type="fail"
      @goBackHome="emit('goBackHome')"
    >
      <template #remark>
        <div class="result-content-remark-item">{{ detail.refundCheckRemark }}</div>
        <div class="result-content-remark-item">
          如有疑问 请联系客服 {{ CustomerServicePhone }}（周一到周五 9:00-17:30）
        </div>
      </template>
    </Result>
  </LoadingLayout>
</template>

<script setup lang="ts">
import { LifeRechargeConstants, useLifeRechargeContext } from '@life-payment/core-vue';
import Result from '../../components/Result/Result.vue';
import { CustomerServicePhone, OssAssets } from '../../constants';
import { useQuery } from '@tanstack/vue-query';
import { computed } from 'vue';
import LoadingLayout from '../../components//Layout/LoadingLayout.vue';

defineOptions({
  name: 'OrderRefundResultView',
});

type Props = {
  title?: string;
  orderNo?: string;
  lifePayOrderType?: LifeRechargeConstants.LifePayOrderTypeEnum;
};

const props = withDefaults(defineProps<Props>(), {
  title: '退款失败',
});

const emit = defineEmits<{
  (e: 'goBackHome'): void;
}>();

const { blLifeRecharge } = useLifeRechargeContext();

const { data: detail, isLoading } = useQuery({
  queryKey: ['blLifeRecharge/getUserLifePayOrderDetail', props.orderNo],
  queryFn: async () => {
    return await blLifeRecharge.services.getUserLifePayOrderDetail(
      { orderNo: props.orderNo },
      {
        showLoading: false,
      }
    );
  },

  enabled: computed(() => !!props.orderNo),
});
</script>
